# Yamado

1. [Description](#description)
2. [Installation](#install)
3. [Use](#use)
4. [Yamado client](#yamado-client)
5. [Package](#package)

## Description

Yamado is a note & journal system with extensions for functioning as a homepage & blog.

Meant to be installed on a server, requires only standard utilities like bash, sed and awk. There are plans for off-line support too. 

The file system is used to store all data. All articles are submitted as a file and stored as a file. The file format is YAML + Markdown.

### Features

* Repository of articles and control interface (yamado add, etc)
* No database needed. Basic storage is based on regular files.
* Conversion to an HTML website. (Requires markdown)
* Atom feed generation. (Requires markdown)

### Licence

AGPL 3.0: http://www.gnu.org/licenses/agpl-3.0.txt

## Resources

* Mailing lists, coming soon.
* [List of websites](https://github.com/orbifx/yamado/wiki/websites-using-yamado) that use _Yamado_.
* [reddit/yamado](https://www.reddit.com/r/yamado/)

## Installation

### Installation for user from git repository

	git clone https://github.com/orbifx/yamado.git
	cd yamado
	./yamado mkuserdirs

### Configuration

The `yamado.conf` file needs to either exist in the `$HOME/.config/yamado/` directory for local installations, or in the `/etc/yamado/` directory for system-wide installations. Otherwise the default values will be used.

User values override system values for user configurable aspects.

The configuration values that should be set are:

- `YMDFQDN`: Fully qualified domain name for generated URLS. e.g. `example.com`
- `YMDFQNPATH`: Path URL where `public_html` is accessible. Empty string if root.
- `YMDTITLE`: Title for your site.
- `YMDUUID`: A UUID for your site, use `uuidgen` or <https://duckduckgo.com/?q=UUID>

Optional values if you know what you are doing:

- `YAMADODIR`: the location of yamado's code. Default: `/usr/lib/yamado` 
- `YAMADOFILES`: published data and metadate directory. Default: `$HOME/yamado`
- `YAMADOPUBLISH`: a monitored for changes directory. Changes are automatically published. Feature requires _incron_. Default: `$YAMADOFILES/publish`
- `YAMADOHTML`: http accessible directory for html output. Default: `$HOME/public_html`

**Notice:** Paths don't end with /.

## Use

Yamado is a system of scripts. The _yamado_ script is the front-end for the whole system. The scripts performing the various functions are split between _bin/_ and _converters/_. You shouldn't have to go in those folders, unless you are looking to hack something. The normal command format is `yamado <command>`. Try `yamado help`.

### Creating an article

The steps:

    yamado form > new_file.ymd
    #edit new_file.ymd
    yamado add new_file.ymd
    yamado publish

The basic flow is running `yamado add file.ymd` to add (copy) this ymd into the system. The file is copied into the designated _YAMADOFILES_ storage and any index file affected is updated.

To save time creating a _ymd_ file from scratch a command, yamado can pipe a form to a file using `yamado form > desired-filename.ymd`. This _ymd_ file can be edited with the preferred text editor and then added with the `yamado add` command.

Once articles have been added, edited or removed, `yamado publish` should be executed to publish the changes. As a shortcut to add & publish a file in one command do `yamado publish <file>` where `<file>` is your file.

### Format

A `.ymd` file has to segments, the YAML header and the Markdown body. Calling `yamado form` prints an empty template header and space for the markdown.
 
### Maintaining articles

- `yamado ls`: Lists all articles in collection.
- `yamado erase datedtitle/_date_/_title_.ymd`: erases article from collection.

*Notice:* erase needs `yamado publish` to update the system.

## Yamado client

Give your yamado installation might be on a remote server, yamado has a small utility called `yamadoclient` to help with maintaining the remote yamado system.

The available commands for _yamadoclient_ are:

* `copykey`: installs your local ssh public key on the server.
* `ls`: lists all added articles.
* `form`: returns any empty template from the server.
* `write`: opens in the editor with on an empty template and uploads it when editor exits.
* `add`: add a local file and its attachments to the server.
* `get`: get an article from the server and return the temporary directory.
* `edit`: edit a file from the server and upload the changes onces finished.
* `publish`: run publish on the server. 

## Package

The files in this directory constitute the yamado system.

`yamado` (bash)
  : Service functions

`yamadoctl` (bash)
  : Service control for owners or administrators.

`bin/`
  : Directory with collection of scripts used by `yamado`.

`share/`
  : Resources shared by other services.

`converters/`
  : Collection of converter scripts from and to YAMADO scripts.

